==> huaweicloudsdkcoc-3.1.140-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/custom_baseline_rule_patch_item.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CustomBaselineRulePatchItem:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'version': 'str',
        'created_time': 'int'
    }

    attribute_map = {
        'name': 'name',
        'version': 'version',
        'created_time': 'created_time'
    }

    def __init__(self, name=None, version=None, created_time=None):
        """CustomBaselineRulePatchItem

        The model defined in huaweicloud sdk

        :param name: 补丁名称
        :type name: str
        :param version: 补丁版本
        :type version: str
        :param created_time: 创建时间
        :type created_time: int
        """
        
        

        self._name = None
        self._version = None
        self._created_time = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if created_time is not None:
            self.created_time = created_time

    @property
    def name(self):
        """Gets the name of this CustomBaselineRulePatchItem.

        补丁名称

        :return: The name of this CustomBaselineRulePatchItem.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CustomBaselineRulePatchItem.

        补丁名称

        :param name: The name of this CustomBaselineRulePatchItem.
        :type name: str
        """
        self._name = name

    @property
    def version(self):
        """Gets the version of this CustomBaselineRulePatchItem.

        补丁版本

        :return: The version of this CustomBaselineRulePatchItem.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this CustomBaselineRulePatchItem.

        补丁版本

        :param version: The version of this CustomBaselineRulePatchItem.
        :type version: str
        """
        self._version = version

    @property
    def created_time(self):
        """Gets the created_time of this CustomBaselineRulePatchItem.

        创建时间

        :return: The created_time of this CustomBaselineRulePatchItem.
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this CustomBaselineRulePatchItem.

        创建时间

        :param created_time: The created_time of this CustomBaselineRulePatchItem.
        :type created_time: int
        """
        self._created_time = created_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomBaselineRulePatchItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.148-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/custom_baseline_rule_patch_item.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CustomBaselineRulePatchItem:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'version': 'str',
        'created_time': 'int'
    }

    attribute_map = {
        'name': 'name',
        'version': 'version',
        'created_time': 'created_time'
    }

    def __init__(self, name=None, version=None, created_time=None):
        r"""CustomBaselineRulePatchItem

        The model defined in huaweicloud sdk

        :param name: 补丁名称
        :type name: str
        :param version: 补丁版本
        :type version: str
        :param created_time: 创建时间
        :type created_time: int
        """
        
        

        self._name = None
        self._version = None
        self._created_time = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if version is not None:
            self.version = version
        if created_time is not None:
            self.created_time = created_time

    @property
    def name(self):
        r"""Gets the name of this CustomBaselineRulePatchItem.

        补丁名称

        :return: The name of this CustomBaselineRulePatchItem.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this CustomBaselineRulePatchItem.

        补丁名称

        :param name: The name of this CustomBaselineRulePatchItem.
        :type name: str
        """
        self._name = name

    @property
    def version(self):
        r"""Gets the version of this CustomBaselineRulePatchItem.

        补丁版本

        :return: The version of this CustomBaselineRulePatchItem.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        r"""Sets the version of this CustomBaselineRulePatchItem.

        补丁版本

        :param version: The version of this CustomBaselineRulePatchItem.
        :type version: str
        """
        self._version = version

    @property
    def created_time(self):
        r"""Gets the created_time of this CustomBaselineRulePatchItem.

        创建时间

        :return: The created_time of this CustomBaselineRulePatchItem.
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        r"""Sets the created_time of this CustomBaselineRulePatchItem.

        创建时间

        :param created_time: The created_time of this CustomBaselineRulePatchItem.
        :type created_time: int
        """
        self._created_time = created_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomBaselineRulePatchItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
